#!/bin/sh


# ----------------------------------------------------------------------------
# Clear the screen if it is supported.
# ----------------------------------------------------------------------------
clearscr()
{
	# check if the terminal environment is set up
	[ "$TERM" ] && clear 2> /dev/null
}

# ----------------------------------------------------------------------------
# Print message
# ----------------------------------------------------------------------------
print()
{
	if [ "${OUTPUT_TYPE}" = "NORMAL" ]; then
		echo $* 
	else
		echo $*  >&2
	fi
}

# ----------------------------------------------------------------------------
# Print message
# ----------------------------------------------------------------------------
print_space()
{
	if [ "${OUTPUT_TYPE}" = "NORMAL" ]; then
		echo $* " " 
	else
		echo $* " "  >&2
	fi
}

# ----------------------------------------------------------------------------
# Display error message.
# ----------------------------------------------------------------------------
error()
{
	print ""
	print -e "    Error: $*!" 
	print ""
	return 0
}

# ----------------------------------------------------------------------------
# Pause.
# ----------------------------------------------------------------------------
pause()
{
	[ $# -ne 0 ] && print -e $*
	print -e "Press [Enter] to continue...\c"
	read tmp
	return 0
}

#============================================================
# result
#
#	Write a return code into a file.  We use this
#	since bash2 can only return a number from 0 to 255. 
#
#============================================================
result () {
	echo "$1 " > $RC
}

# ----------------------------------------------------------------------------
# Prompt user for input.
# ----------------------------------------------------------------------------
prompt()
{
	print -n "$* "
	read CMD rest
	return 0
}

# ----------------------------------------------------------------------------
# Get Number 
# ----------------------------------------------------------------------------
get_num()
{
	while prompt "$* "
	do	
		case $CMD in
			[0-9]*)	result $CMD
				return 0
				;;
			*)	getyn "Wrong number, try it again?" || return 1
				;;
		esac
	done
	return 1
}

# ----------------------------------------------------------------------------
# Get Yes/No
# ----------------------------------------------------------------------------
getyn()
{
	while prompt "$* (y/n)"
	do	case $CMD in
			[yY])	return 0
				;;
			[nN])	return 1
				;;
			*)	print -e "\nPlease answer y or n"
				;;
		esac
	done
}

verify_netgraph()
{
	local unload=0

	ret=`kldstat | grep netgraph`
	if [ -z "$ret" ]; then
		eval "kldload netgraph >/dev/null"
		if [ $? -ne 0 ]; then
			NETGRAPH="NO"
			return 0			
		fi
		unload=1
	fi
	echo " " > $WRKDIR/include/opt_netgraph.h
	if [ $unload -eq 1 ]; then
		eval "kldunload netgraph >/dev/null 2>/dev/null"
	fi
	return 0	
}

enable_compilation_modes()
{
	local PROT_MATCH=NO
	local mode=$1
	local ARG

	ARG=${2:-NO}

	echo "$mode" | grep "TDM" > /dev/null
	if [ $? -eq 0 ]; then
		mode="$mode AFT_TE1 AFT_RM"	
	fi

	echo "$mode" | grep "SCARD" > /dev/null	
	if [ $? -eq 0 ]; then
		SCARD_PROT=YES
	fi
	
	echo "$mode" | grep "FR" > /dev/null	
	if [ $? -eq 0 ]; then
		FR_PROT=YES
	fi
	
	echo "$mode" | grep "CHDLC" > /dev/null	
	if [ $? -eq 0 ]; then
		CHDLC_PROT=YES
	fi
	
	echo "$mode" | grep "PPP" > /dev/null	
	if [ $? -eq 0 ]; then
		PPP_PROT=YES	
	fi
	
	echo "$mode" | grep "ADSL" > /dev/null
	if [ $? -eq 0 ]; then
		ADSL_PROT=YES
	fi

	echo "$mode" | grep "AFT_TE1" > /dev/null
	if [ $? -eq 0 ]; then
		AFT_TE1_PROT=YES
	fi

	echo "$mode" | grep "AFT_RM" > /dev/null
	if [ $? -eq 0 ]; then
		AFT_RM_PROT=YES
	fi

	echo "$mode" | grep "AFT_TE3" > /dev/null
	if [ $? -eq 0 ]; then
		AFT_TE3_PROT=YES
	fi

	echo "$mode" | grep "AFT_56K" > /dev/null
	if [ $? -eq 0 ]; then
		AFT_56K_PROT=YES
	fi

	echo "$mode" | grep "AFT_SER" > /dev/null
	if [ $? -eq 0 ]; then
		AFT_SERIAL_PROT=YES
	fi

	echo "$mode" | grep "HWEC" > /dev/null
	if [ $? -eq 0 ]; then
		HWEC_SUPPORT=YES
	fi

	echo "$mode" | grep "TDM" > /dev/null
	if [ $? -eq 0 ]; then
		TDM_PROT=YES
	fi

	return 0
}

#
# Create Makefile.in file
#
create_makefilein()
{
	# Create Makefile.in for WANPIPE package
	WANPIPE_MAKEFILEIN=$WRKDIR/sources/Makefile.in
	cat > $WANPIPE_MAKEFILEIN << ENDOFTEXT
#
# ${DATE}
#
# Makefile.in for Sangoma WANPIPE-port project
#
ENDOFTEXT

	echo "NBPFILTER=" >> ${WANPIPE_MAKEFILEIN}
	echo "ALTQ=" >> ${WANPIPE_MAKEFILEIN}
	# Enable/Disable NETGRAPH
	if [ "$NETGRAPH" = "YES" ]; then
		echo "WAN_NETGRAPH=YES" >> ${WANPIPE_MAKEFILEIN}
	else
		echo "WAN_NETGRAPH=NO" >> ${WANPIPE_MAKEFILEIN}
	fi

	echo "## Cards:" >> ${WANPIPE_MAKEFILEIN}
	echo "# Compile Sangoma S-Series card support" >> ${WANPIPE_MAKEFILEIN}
	if [ "$SCARD_PROT" = "YES" ]; then
		echo "WANPIPE_SCARD=YES" >> ${WANPIPE_MAKEFILEIN}
	else
		echo "WANPIPE_SCARD=NO" >> ${WANPIPE_MAKEFILEIN}
	fi
	echo "# Compile Sangoma S518 ADSL support" >> ${WANPIPE_MAKEFILEIN}
	if [ "$ADSL_PROT" = "YES" ]; then
		echo "WANPIPE_ADSL=YES" >> ${WANPIPE_MAKEFILEIN}
	else
		echo "WANPIPE_ADSL=NO" >> ${WANPIPE_MAKEFILEIN}
	fi
	echo "# Compile Sangoma A101/A102/A104d/A108 T1/E1 support" >> ${WANPIPE_MAKEFILEIN}
	if [ "$AFT_TE1_PROT" = "YES" ]; then
		echo "WANPIPE_AFT_TE1=YES" >> ${WANPIPE_MAKEFILEIN}
	else
		echo "WANPIPE_AFT_TE1=NO" >> ${WANPIPE_MAKEFILEIN}
	fi
	echo "# Compile Sangoma A200/A400 FXS/FXO support" >> ${WANPIPE_MAKEFILEIN}
	if [ "$AFT_RM_PROT" = "YES" ]; then
		echo "WANPIPE_AFT_RM=YES" >> ${WANPIPE_MAKEFILEIN}
	else
		echo "WANPIPE_AFT_RM=NO" >> ${WANPIPE_MAKEFILEIN}
	fi
	echo "# Compile Sangoma A056 56K support" >> ${WANPIPE_MAKEFILEIN}
	if [ "$AFT_56K_PROT" = "YES" ]; then
		echo "WANPIPE_AFT_56K=YES" >> ${WANPIPE_MAKEFILEIN}
	else
		echo "WANPIPE_AFT_56K=NO" >> ${WANPIPE_MAKEFILEIN}
	fi
	echo "# Compile Sangoma A140 Serial support" >> ${WANPIPE_MAKEFILEIN}
	if [ "$AFT_SERIAL_PROT" = "YES" ]; then
		echo "WANPIPE_AFT_SERIAL=YES" >> ${WANPIPE_MAKEFILEIN}
	else
		echo "WANPIPE_AFT_SERIAL=NO" >> ${WANPIPE_MAKEFILEIN}
	fi
	echo "# Compile Sangoma AFT BRI support" >> ${WANPIPE_MAKEFILEIN}
	if [ "$AFT_BRI_PROT" = "YES" ]; then
		echo "WANPIPE_AFT_BRI=YES" >> ${WANPIPE_MAKEFILEIN}
	else
		echo "WANPIPE_AFT_BRI=NO" >> ${WANPIPE_MAKEFILEIN}
	fi
	echo "# Compile Sangoma A300 support" >> ${WANPIPE_MAKEFILEIN}
	if [ "$AFT_TE3_PROT" = "YES" ]; then
		echo "WANPIPE_AFT_TE3=YES" >> ${WANPIPE_MAKEFILEIN}
	else
		echo "WANPIPE_AFT_TE3=NO" >> ${WANPIPE_MAKEFILEIN}
	fi

	echo "## Protocols:" >> ${WANPIPE_MAKEFILEIN}
	echo "# Compile Sangoma CHDLC support" >> ${WANPIPE_MAKEFILEIN}
	if [ "$CHDLC_PROT" = "YES" ]; then
		echo "WANPIPE_CHDLC=YES" >> ${WANPIPE_MAKEFILEIN}
	else
		echo "WANPIPE_CHDLC=NO" >> ${WANPIPE_MAKEFILEIN}
	fi
	echo "# Compile Sangoma FR support" >> ${WANPIPE_MAKEFILEIN}
	if [ "$FR_PROT" = "YES" ]; then
		echo "WANPIPE_FR=YES" >> ${WANPIPE_MAKEFILEIN}
	else
		echo "WANPIPE_FR=NO" >> ${WANPIPE_MAKEFILEIN}
	fi
	echo "# Compile Sangoma PPP support" >> ${WANPIPE_MAKEFILEIN}
	if [ "$PPP_PROT" = "YES" ]; then
		echo "WANPIPE_PPP=YES" >> ${WANPIPE_MAKEFILEIN}
	else
		echo "WANPIPE_PPP=NO" >> ${WANPIPE_MAKEFILEIN}
	fi
	echo "# Compile Sangoma TDM interface" >> ${WANPIPE_MAKEFILEIN}
	if [ "$TDM_PROT" = "YES" ]; then
		echo "WANPIPE_TDM=YES" >> ${WANPIPE_MAKEFILEIN}
	else
		echo "WANPIPE_TDM=NO" >> ${WANPIPE_MAKEFILEIN}
	fi

	echo "# Compile WANPIPE HW Echo Canceller support" >> ${WANPIPE_MAKEFILEIN}
	if [ "$HWEC_SUPPORT" = "YES" ]; then
		echo "WANPIPE_HWEC=YES" >> ${WANPIPE_MAKEFILEIN}
	else
		echo "WANPIPE_HWEC=NO" >> ${WANPIPE_MAKEFILEIN}
	fi

	cat >> ${WANPIPE_MAKEFILEIN} << ENDOFTEXT

WAN_GLB_CFLAGS=

.if defined(NBPFILTER)
WAN_GLB_CFLAGS+=-DNBPFILTER
.endif

.if defined(ALTQ)
WAN_GLB_CFLAGS+=-DALTQ
.endif

.if defined(ENABLE_SPPP)
WAN_GLB_CFLAGS+=-DENABLE_SPPP
.endif

.if \${WAN_NETGRAPH} == YES
WAN_GLB_CFLAGS+=-DNETGRAPH -I$SYSDIR/$KCOMPILE_DIR/$KNAME
.endif
.if \${WANPIPE_AFT_56K} == YES || \${WANPIPE_AFT_TE1} == YES || \${WANPIPE_AFT_RM} == YES || \${WANPIPE_AFT_SERIAL} == YES
WAN_GLB_CFLAGS += -DCONFIG_PRODUCT_WANPIPE_AFT_BASE -DCONFIG_PRODUCT_WANPIPE_AFT_CORE
.endif

.if \${WANPIPE_HWEC} == YES
WAN_GLB_CFLAGS += -DCONFIG_WANPIPE_HWEC
.endif

ENDOFTEXT

	return 0
}

#
# Create FreeBSD Kernel Makefiles
#
create_freebsd_kernel_makefiles()
{
	if [ $OS_MAJOR_VER -ge "5" ]; then
		KMODDEPS_ARG="MODULE_DEPEND"
	else
		KMODDEPS_ARG="KMODDEPS"
	fi

	CFLAGS="-Wunused -I/sys ${WAN_KERNEL_CFLAGS}"
	
	########################################################
	# Create Mafile for SOURCES
	SOURCES_MAKEFILE=$WRKDIR/sources/Makefile
	SOURCES_DIRS="lip sdladrv wan_aften wanec wanpipe wanrouter wantools"
	cat > ${SOURCES_MAKEFILE} << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma SOURCES
#

SUBDIR	= ${SOURCES_DIRS}

.include <bsd.subdir.mk>
ENDOFTEXT
	eval "chmod +x $SOURCES_MAKEFILE"

	########################################################
	# Create Makefile for WANPIPE module
	WANPIPE_MAKEFILE=$WRKDIR/sources/wanpipe/Makefile
	WANPIPE_DEPENDS="wanrouter sdladrv"
	WANPIPE_SRCS="sdlamain.c sdla_cdev.c wanpipe_abstr.c wanpipe_utils.c wanpipe_bsd_iface.c"
	WANPIPE_OBJS=
	WANPIPE_CFLAGS="-I../wanec/oct6100api -I../wanec/oct6100api/include -I../wanec/oct6100api/include/oct6100api -I../../include ${CFLAGS}"

	cat > $WANPIPE_MAKEFILE << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma WANPIPE module
#
.if exists(../Makefile.in)
.include "../Makefile.in"
.endif

OS!=	/usr/bin/uname -s

KLDMOD		= true
KMOD		= wanpipe
DESTDIR		= ${WAN_BUILDDIR}
KMODDIR		= ${WAN_MODULE_DIR}
${KMODDEPS_ARG}	= ${WANPIPE_DEPENDS}
OBJS		+= ${WANPIPE_OBJS}
SRCS		= ${WANPIPE_SRCS}
CFLAGS		+= \${WAN_GLB_CFLAGS} ${WANPIPE_CFLAGS}
WERROR		= -Wall
ZAPTEL_CFLAGS	= ${ZAPTEL_CFLAGS}

# Core files
.if \${WANPIPE_AFT_TE1} == YES
SRCS += sdla_xilinx.c sdla_aft_te1.c
CFLAGS += -DCONFIG_PRODUCT_WANPIPE_AFT -DCONFIG_PRODUCT_WANPIPE_AFT_TE1
.elif \${WANPIPE_AFT_56K} == YES || \${WANPIPE_AFT_RM} == YES || \${WANPIPE_AFT_BRI} == YES || \${WANPIPE_AFT_SERIAL} == YES
SRCS += sdla_aft_te1.c
.endif
.if \${WANPIPE_AFT_56K} == YES
CFLAGS += -DCONFIG_PRODUCT_WANPIPE_AFT_56K
.endif
.if \${WANPIPE_AFT_RM} == YES
CFLAGS += -DCONFIG_PRODUCT_WANPIPE_AFT_RM
.endif
.if \${WANPIPE_AFT_BRI} == YES
CFLAGS += -DCONFIG_PRODUCT_WANPIPE_AFT_BRI
.endif
.if \${WANPIPE_AFT_SERIAL} == YES
CFLAGS += -DCONFIG_PRODUCT_WANPIPE_AFT_SERIAL
.endif
.if \${WANPIPE_AFT_TE3} == YES
SRCS += sdla_aft_te3.c
CFLAGS += -DCONFIG_PRODUCT_WANPIPE_AFT_TE3
.endif
.if \${WANPIPE_ADSL} == YES
SRCS	+= sdla_adsl.c sdla_adsl_tty.c
CFLAGS	+= -DCONFIG_PRODUCT_WANPIPE_ADSL
OBJS	+= wanpipe_adsl.o
.endif
.if \${WANPIPE_SCARD} == YES
SRCS	+= sdla_ft1.c wanpipe_multppp.c
CFLAGS	+= -DCONFIG_PRODUCT_WANPIPE_SCARD
.endif

# Sub-core files
.if \${WANPIPE_AFT_TE1} == YES || \${WANPIPE_AFT_56K} == YES || \${WANPIPE_AFT_SERIAL} == YES
SRCS += aft_a104.c
.endif
.if \${WANPIPE_AFT_RM} == YES
SRCS += aft_analog.c
.endif
.if \${WANPIPE_AFT_BRI} == YES
SRCS += aft_bri.c
.endif

# Framer files
.if \${WANPIPE_AFT_TE1} == YES
SRCS += sdla_te1.c sdla_8te1.c
.elif \${WANPIPE_SCARD} == YES
SRCS += sdla_te1.c
.endif
.if \${WANPIPE_AFT_RM} == YES
SRCS += sdla_remora.c
.endif
.if \${WANPIPE_AFT_SERIAL} == YES
SRCS += sdla_serial.c
.endif
.if \${WANPIPE_SCARD} == YES || \${WANPIPE_AFT_56K} == YES
SRCS += sdla_56k.c
.endif
.if \${WANPIPE_AFT_TE3} == YES
SRCS += sdla_te3.c
.endif

# Protocol files
.if \${WANPIPE_SCARD} == YES && \${WANPIPE_CHDLC} == YES
SRCS	+= sdla_chdlc.c
CFLAGS	+= -DCONFIG_PRODUCT_WANPIPE_CHDLC
.endif
.if \${WANPIPE_SCARD} == YES && \${WANPIPE_FR} == YES
SRCS	+= sdla_fr.c
CFLAGS	+= -DCONFIG_PRODUCT_WANPIPE_FR
.endif
.if \${WANPIPE_SCARD} == YES && \${WANPIPE_PPP} == YES
SRCS	+= sdla_ppp.c
CFLAGS	+= -DCONFIG_PRODUCT_WANPIPE_PPP
.endif

# TDM interface
.if \${WANPIPE_TDM} == YES
${KMODDEPS_ARG}	+= zaptel
CFLAGS	+= \${ZAPTEL_CFLAGS} -DCONFIG_PRODUCT_WANPIPE_TDM_VOICE 
SRCS	+= sdla_tdmv.c sdla_remora_tdmv.c sdla_tdmv_dummy.c
.endif

.if \${WAN_NETGRAPH} == YES
SRCS	+= wan_ng_iface.c 
.endif

wanpipe_adsl.o:
	\rm -rf wanpipe_adsl.o
	ln -s ./adsl/wanpipe_adsl_\$(OS)_\$(MACHINE_ARCH).o	wanpipe_adsl.o

.include <bsd.kmod.mk>
ENDOFTEXT

	eval "chmod +x $WANPIPE_MAKEFILE"

	########################################################
	# Create Makefile for WANROUTER module
	WANROUTER_MAKEFILE=$WRKDIR/sources/wanrouter/Makefile
	WANROUTER_DEPENDS="sdladrv"
	WANROUTER_SRCS="wanmain.c wanproc.c"
	WANROUTER_CFLAGS="-I../../include ${CFLAGS}"
	cat > $WANROUTER_MAKEFILE << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma WANROUTER module
#
.if exists(../Makefile.in)
.include "../Makefile.in"
.endif

KLDMOD		= true
DESTDIR		= ${WAN_BUILDDIR}
KMODDIR		= ${WAN_MODULE_DIR}
KMOD		= wanrouter
${KMODDEPS_ARG}	= ${WANROUTER_DEPENDS}
SRCS		= ${WANROUTER_SRCS}
CFLAGS		+= ${WANROUTER_CFLAGS} \${WAN_GLB_CFLAGS}
WERROR		= -Wall

EXPORT_SYMS= _register_wan_device _unregister_wan_device

.include <bsd.kmod.mk>
ENDOFTEXT
	eval "chmod +x $WANROUTER_MAKEFILE"

	########################################################
	# Create Makefile for SDLADRV module
	SDLADRV_MAKEFILE=$WRKDIR/sources/sdladrv/Makefile
	SDLADRV_SRCS="sdladrv.c sdladrv_fe.c sdladrv_utils.c sdla_bsd.c"
	if [ $OS_MAJOR_VER = "3" ]; then
		SDLADRV_EXT_HDRS="device_if.h bus_if.h"
	elif  [ $OS_MAJOR_VER -ge "4" ]; then
		SDLADRV_EXT_HDRS="device_if.h bus_if.h pci_if.h"
	fi

	SDLADRV_CFLAGS="-O0 -I../../include ${CFLAGS}"
	cat > $SDLADRV_MAKEFILE << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma SDLADRV module
#
.if exists(../Makefile.in)
.include "../Makefile.in"
.endif

KLDMOD		= true
DESTDIR		= ${WAN_BUILDDIR}
KMODDIR		= ${WAN_MODULE_DIR}
KMOD		= sdladrv
SRCS		= ${SDLADRV_SRCS} ${SDLADRV_EXT_HDRS}
CFLAGS		+= ${SDLADRV_CFLAGS} ${SDLADRV_CFLAGS} \${WAN_GLB_CFLAGS}
CFLAGS		+= -DSDLA_AUTO_PROBE
CLEANFILES	+= ${SDLADRV_EXT_HDRS} 
ENDOFTEXT

	if [ $OS_MAJOR_VER = "3" ]; then
		cat >> $SDLADRV_MAKEFILE << ENDOFTEXT
device_if.h: $SYSDIR/kern/makedevops.pl $SYSDIR/kern/device_if.m
	     perl $SYSDIR/kern/makedevops.pl -h $SYSDIR/kern/device_if.m
 
bus_if.h: $SYSDIR/kern/makedevops.pl $SYSDIR/kern/bus_if.m
	  perl $SYSDIR/kern/makedevops.pl -h $SYSDIR/kern/bus_if.m
ENDOFTEXT
	elif  [ $OS_MAJOR_VER = "4" ]; then
		cat >> $SDLADRV_MAKEFILE << ENDOFTEXT
device_if.h: $SYSDIR/kern/makedevops.pl $SYSDIR/kern/device_if.m
	     perl $SYSDIR/kern/makedevops.pl -h $SYSDIR/kern/device_if.m
 
bus_if.h: $SYSDIR/kern/makedevops.pl $SYSDIR/kern/bus_if.m
	  perl $SYSDIR/kern/makedevops.pl -h $SYSDIR/kern/bus_if.m

pci_if.h: $SYSDIR/kern/makedevops.pl $SYSDIR/pci/pci_if.m
	  perl $SYSDIR/kern/makedevops.pl -h $SYSDIR/pci/pci_if.m
ENDOFTEXT
	fi

	cat >> $SDLADRV_MAKEFILE << ENDOFTEXT
.include <bsd.kmod.mk>
ENDOFTEXT
	eval "chmod +x $SDLADRV_MAKEFILE"

	########################################################
	# Create Makefile for Lip Layer module
	LIP_MAKEFILE=$WRKDIR/sources/lip/Makefile
	LIP_DEPENDS="wanpipe wanrouter sdladrv"
	LIP_SRCS="wanpipe_lip_iface.c wanpipe_lip_sub.c wanpipe_lip_prot.c wanpipe_lip_netdev.c wanpipe_lip_bh.c wanpipe_lip_ipx.c"
	LIP_PROT_OBJS="wanpipe_fr.o wanpipe_sppp.o"
	LIP_CFLAGS="${CFLAGS} -Iinclude -I../include -I../../include -DWANPIPE_LIP_IFNET_QUEUE_POLICY_INIT_OFF -DWANLIP_DRIVER"
	cat > $LIP_MAKEFILE << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma Lip Layer module
#
.if exists(../Makefile.in)
.include "../Makefile.in"
.endif

OS!=	/usr/bin/uname -s

KLDMOD		= true
KMOD		= wanpipe_lip
DESTDIR		= ${WAN_BUILDDIR}
KMODDIR		= ${WAN_MODULE_DIR}
${KMODDEPS_ARG}	= ${LIP_DEPENDS}
SRCS		= ${LIP_SRCS}
CFLAGS		+= ${LIP_CFLAGS} ${LIP_CFLAGS} \${WAN_GLB_CFLAGS}

.if \${WANPIPE_CHDLC} == YES || \${WANPIPE_PPP} == YES
OBJS += wanpipe_sppp.o
.endif
.if \${WANPIPE_FR} == YES
OBJS += wanpipe_fr.o
.endif

.if \${WANPIPE_CHDLC} == YES
CFLAGS	+= -DCONFIG_PRODUCT_WANPIPE_CHDLC
.endif

.if \${WANPIPE_FR} == YES
CFLAGS	+= -DCONFIG_PRODUCT_WANPIPE_FR
.endif

.if \${WANPIPE_PPP} == YES
CFLAGS	+= -DCONFIG_PRODUCT_WANPIPE_PPP
.endif

wanpipe_fr.o:
	\rm -rf wanpipe_fr.o
	ln -s ./fr/wanpipe_fr_\$(OS)_\$(MACHINE_ARCH).o	wanpipe_fr.o

wanpipe_sppp.o:
	\rm -rf wanpipe_spppr.o
	ln -s ./sppp/wanpipe_sppp_\$(OS)_\$(MACHINE_ARCH).o	wanpipe_sppp.o

.include <bsd.kmod.mk>
ENDOFTEXT
	eval "chmod +x $LIP_MAKEFILE"

	########################################################
	# Create Makefile for WAN_AFTEN module
	WAN_AFTEN_MAKEFILE=$WRKDIR/sources/wan_aften/Makefile
	WAN_AFTEN_DEPENDS="sdladrv"
	WAN_AFTEN_SRCS="wan_aften.c wanpipe_bsd_iface.c"
	WAN_AFTEN_CFLAGS="-I../../include ${CFLAGS} -DWAN_AFTEN" 
	cat > $WAN_AFTEN_MAKEFILE << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma WAN_AFTEN module
#
.if exists(../Makefile.in)
.include "../Makefile.in"
.endif

KLDMOD		= true
KMOD		= wan_aften
DESTDIR		= ${WAN_BUILDDIR}
KMODDIR		= ${WAN_MODULE_DIR}
${KMODDEPS_ARG}	= ${WAN_AFTEN_DEPENDS}
SRCS		= ${WAN_AFTEN_SRCS}
CFLAGS		+= ${WAN_AFTEN_CFLAGS} \${WAN_GLB_CFLAGS}

.include <bsd.kmod.mk>
ENDOFTEXT
	eval "chmod +x $WAN_AFTEN_MAKEFILE"

	########################################################
	# Create Makefile for HW WANEC module
	WANEC_MAKEFILE=$WRKDIR/sources/wanec/Makefile
	WANEC_DEPENDS="wanrouter"
	WANEC_SRCS="wanec_iface.c  wanec_cmd.c wanec_utils.c octapi_bt0.c octapi_largmath.c octapi_llman.c oct6100_mask_interrupts.c oct6100_adpcm_chan.c oct6100_channel.c oct6100_chip_open.c oct6100_chip_stats.c oct6100_conf_bridge.c  oct6100_debug.c oct6100_events.c oct6100_interrupts.c oct6100_memory.c oct6100_miscellaneous.c oct6100_mixer.c oct6100_phasing_tsst.c oct6100_playout_buf.c oct6100_remote_debug.c oct6100_tlv.c oct6100_tone_detection.c oct6100_tsi_cnct.c oct6100_tsst.c oct6100_user.c"
	WANEC_CFLAGS="${WANEC_CFLAGS} -I../../include -Ioct6100api/include -Ioct6100api/include/oct6100api -Ioct6100api/include/apilib -Ioct6100api/include/octrpc -Ioct6100api"
	cat > $WANEC_MAKEFILE << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma Hardware Echo Canceller module
#
.if exists(../Makefile.in)
.include "../Makefile.in"
.endif
.PATH:	.	oct6100api/

KLDMOD		= true
KMOD		= wanec
DESTDIR		= ${WAN_BUILDDIR}
KMODDIR		= ${WAN_MODULE_DIR}
${KMODDEPS_ARG}	= ${WANEC_DEPENDS}
SRCS		= ${WANEC_SRCS}
CFLAGS		+= ${WANEC_CFLAGS} ${WANEC_CFLAGS} \${WAN_GLB_CFLAGS}

.include <bsd.kmod.mk>
ENDOFTEXT
	eval "chmod +x $WANEC_MAKEFILE"

	return 0
}

#
# Create OpenBSD Makefile file
#
create_openbsd_kernel_makefiles()
{
	CFLAGS="-Wunused -Wall -Werror -I/sys -O0 -fno-builtin-printf -fno-builtin-log"

	if  [ $OS_MAJOR_VER = "3" ] && [ $OS_MINOR_VER = "4" ]; then
		OBJ_PREFIX="_aout"
	else 
		OBJS_PREFIX=

	fi
	
	########################################################
	# Create Makefile for WANPIPE module
	WANPIPE_MAKEFILE=$WRKDIR/sources/wanpipe/Makefile
	WANPIPE_OBJS=
	WANPIPE_SRCS="wanmain.c wanproc.c sdladrv.c sdladrv_fe.c sdladrv_utils.c sdlamain.c sdla_ft1.c sdla_56k.c sdla_cdev.c wanpipe_abstr.c wanpipe_utils.c wanpipe_bsd_iface.c"
	WANPIPE_CFLAGS="-I../../include ${CFLAGS}"
	LIP_SRCS="wanpipe_lip_iface.c wanpipe_lip_sub.c wanpipe_lip_prot.c wanpipe_lip_netdev.c wanpipe_lip_bh.c"
	LIP_PROT_OBJS="wanpipe_fr.o wanpipe_sppp.o"
	LIP_CFLAGS="-DWANLIP_DRIVER"

	cat > $WANPIPE_MAKEFILE << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma WANPIPE module
#
.if exists(../Makefile.in)
.include "../Makefile.in"
.endif

.if \${WANPIPE_HWEC} == YES
.PATH:	.	oct6100api/
.endif

OS!=	/usr/bin/uname -s

LKM		= wanpipe
DESTDIR		= ${WAN_BUILDDIR}
SRCS		= ${WANPIPE_SRCS} ${LIP_SRCS}
OBJS		+= ${WANPIPE_OBJS} ${LIP_PROT_OBJS}
POSTINSTALL	= create_cdev
CFLAGS		+= ${WANPIPE_CFLAGS} \${WAN_GLB_CFLAGS} ${WANPIPE_CFLAGS} ${LIP_CFLAGS}
NOMAN		= noman

.if \${WANPIPE_CHDLC} == YES
SRCS	+= sdla_chdlc.c
CFLAGS	+= -DCONFIG_PRODUCT_WANPIPE_CHDLC
.endif
.if \${WANPIPE_FR} == YES
SRCS	+= sdla_fr.c
CFLAGS	+= -DCONFIG_PRODUCT_WANPIPE_FR
.endif
.if \${WANPIPE_PPP} == YES
SRCS	+= sdla_ppp.c
CFLAGS	+= -DCONFIG_PRODUCT_WANPIPE_PPP
.endif
.if \${WANPIPE_ADSL} == YES
SRCS	+=  sdla_adsl.c sdla_adsl_tty.c
OBJS	+= wanpipe_adsl.o
.endif
.if \${WANPIPE_AFT_TE1} == YES
SRCS	+= sdla_aft_te1.c sdla_xilinx.c sdla_te1.c sdla_8te1.c aft_a104.c
CFLAGS	+= -DCONFIG_PRODUCT_WANPIPE_AFT -DCONFIG_PRODUCT_WANPIPE_AFT_TE1
.endif
.if \${WANPIPE_AFT_RM} == YES
SRCS	+= sdla_remora.c aft_analog.c
CFLAGS	+= -DCONFIG_PRODUCT_WANPIPE_AFT_RM
.endif
.if \${WANPIPE_AFT_TE3} == YES
SRCS	+= sdla_aft_te3.c sdla_te3.c
CFLAGS	+= -DCONFIG_PRODUCT_WANPIPE_AFT_TE3
.endif
.if \${WANPIPE_TDM} == YES
SRCS	+= sdla_tdmv.c sdla_remora_tdmv.c sdla_tdmv_dummy.c
CFLAGS	+= -DCONFIG_PRODUCT_WANPIPE_TDM_VOICE -I$ZAPTEL_CFLAGS
.endif
.if \${WANPIPE_HWEC} == YES
SRCS	+= wanec_iface.c  wanec_cmd.c wanec_utils.c octapi_bt0.c octapi_largmath.c octapi_llman.c oct6100_mask_interrupts.c oct6100_adpcm_chan.c oct6100_channel.c oct6100_chip_open.c oct6100_chip_stats.c oct6100_conf_bridge.c  oct6100_debug.c oct6100_events.c oct6100_interrupts.c oct6100_memory.c oct6100_miscellaneous.c oct6100_mixer.c oct6100_phasing_tsst.c oct6100_playout_buf.c oct6100_remote_debug.c oct6100_tlv.c oct6100_tone_detection.c oct6100_tsi_cnct.c oct6100_tsst.c oct6100_user.c
CFLAGS	+= -DCONFIG_WANPIPE_HWEC -Ioct6100api/include -Ioct6100api/include/apilib -Ioct6100api/include/octrpc -Ioct6100api
.endif

wanpipe_adsl.o:
	\rm -rf wanpipe_adsl.o
	ln -s adsl/wanpipe_adsl_\$(OS)_\$(MACHINE_ARCH)${OBJS_PREFIX}.o	wanpipe_adsl.o

wanpipe_fr.o:
	\rm -rf wanpipe_fr.o
	ln -s ./fr/wanpipe_fr_\$(OS)_\$(MACHINE_ARCH)${OBJS_PREFIX}.o	wanpipe_fr.o

wanpipe_sppp.o:
	\rm -rf wanpipe_spppr.o
	ln -s ./sppp/wanpipe_sppp_\$(OS)_\$(MACHINE_ARCH)${OBJS_PREFIX}.o	wanpipe_sppp.o

cleanall:

.include <bsd.lkm.mk>
ENDOFTEXT
	eval "chmod +x $WANPIPE_MAKEFILE"

	########################################################
	# Create Makefile for WAN_AFTEN module
	WAN_AFTEN_MAKEFILE=$WRKDIR/sources/wan_aften/Makefile
	WAN_AFTEN_SRCS="wan_aften.c wanpipe_bsd_iface.c"
	WAN_AFTEN_CFLAGS="-I../../include ${CFLAGS}"
	cat > $WAN_AFTEN_MAKEFILE << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma WAN_AFTEN module
#

LKM	= wan_aften
DESTDIR	= ${WAN_BUILDDIR}
SRCS	= ${WAN_AFTEN_SRCS}
CFLAGS	+= ${WAN_AFTEN_CFLAGS} 
NOMAN	=

.include <bsd.lkm.mk>
ENDOFTEXT
	eval "chmod +x $WAN_AFTEN_MAKEFILE"

}


#
# Create Application Makefile
#
create_appl_makefiles()
{
	if [ "$OSYSTEM" = "FreeBSD" ]; then
		NCURSES_LIB="-lncurses"
	elif [ "$OSYSTEM" = "OpenBSD" ]; then
		NCURSES_LIB="-lcurses"
	else
		NCURSES_LIB="-lcurses"
	fi

	if [ "$OSYSTEM" = "FreeBSD" ]; then
		if [ $OS_MAJOR_VER -ge "6" ]; then
			NOMAN_ARG="NO_MAN"
		else
			NOMAN_ARG="NOMAN"
		fi
	else
		NOMAN_ARG="NOMAN"
	fi
	APPL_CFLAGS="-Wall -I."
	APPL_CXXFLAGS="-Wall -I."

	########################################################
	# Create Mafile for WANTOOLS utilites
	WANTOOLS_MAKEFILE=$WRKDIR/sources/wantools/Makefile
	WANTOOLS_DIRS="ft1 lxdialog sdladump wan_aftup wan_plxctrl wancfg wanconfig wanec_client wanpipemon wanpipemon_legacy"
	cat > ${WANTOOLS_MAKEFILE} << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma WANTOOLS utilities
#
ENDOFTEXT
	cat >> ${WANTOOLS_MAKEFILE} << ENDOFTEXT

SUBDIR	= ${WANTOOLS_DIRS}

.include <bsd.subdir.mk>
ENDOFTEXT
	eval "chmod +x $WANTOOLS_MAKEFILE"

	########################################################
	# Create Mafile for WANPIPEMON utility
	WANPIPEMON_MAKEFILE=$WRKDIR/sources/wantools/wanpipemon/Makefile
	WANPIPEMON_SRCS="wanpipemon.c cpipemon.c fpipemon.c ppipemon.c dslpipemon.c atmpipemon.c aftpipemon.c fe_lib.c unixio.c xml_lib.c wangui.c checklist.c menubox.c  inputbox.c util.c prot_trace.c wanpipe_hdlc.c"
	WANPIPEMON_CFLAGS="-DWANPIPEMON_GUI -DLOCALE -DCURSES_LOC=\"<ncurses.h>\" -I../../../include"
	WANPIPEMON_LDFLAGS="-s -L. ${NCURSES_LIB}"
	WANPIPEMON_COPTS="${APPL_CFLAGS} -I../ft1 -I../lxdialog -I../wan_hdlc_eng"
	cat > ${WANPIPEMON_MAKEFILE} << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma WANPIPEMON utility
#
ENDOFTEXT
	echo ".PATH:	../ft1 ../lxdialog ../wan_hdlc_eng"	>> ${WANPIPEMON_MAKEFILE}
	cat >> ${WANPIPEMON_MAKEFILE} << ENDOFTEXT

BINDIR	= ${WAN_BIN_DIR}
DESTDIR	= ${WAN_BUILDDIR}
PROG	= wanpipemon
SRCS	= ${WANPIPEMON_SRCS}
CFLAGS	+= ${WANPIPEMON_CFLAGS}
LDFLAGS	+= ${WANPIPEMON_LDFLAGS}
COPTS	+= ${WANPIPEMON_COPTS}
${NOMAN_ARG} 	=

.include <bsd.prog.mk>
ENDOFTEXT
	eval "chmod +x $WANPIPEMON_MAKEFILE"

	########################################################
	# Create Mafile for WANPIPEMON_legacy utility
	WANPIPEMON_LEGACY_MAKEFILE=$WRKDIR/sources/wantools/wanpipemon_legacy/Makefile
	WANPIPEMON_LEGACY_SRCS="wanpipemon_legacy.c cpipemon.c fpipemon.c ppipemon.c dslpipemon.c atmpipemon.c aftpipemon.c fe_lib.c unixio.c xml_lib.c wangui.c checklist.c menubox.c  inputbox.c util.c prot_trace.c"
	WANPIPEMON_LEGACY_CFLAGS="-DWANPIPEMON_GUI -DLOCALE -DCURSES_LOC=\"<ncurses.h>\"  -I../../../include"
	WANPIPEMON_LEGACY_LDFLAGS="-s -L. ${NCURSES_LIB}"
	WANPIPEMON_LEGACY_COPTS="${APPL_CFLAGS} -I../ft1 -I../lxdialog"
	cat > ${WANPIPEMON_LEGACY_MAKEFILE} << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma WANPIPEMON legacy utility
#
ENDOFTEXT
	echo ".PATH:	../ft1 ../lxdialog"	>> ${WANPIPEMON_LEGACY_MAKEFILE}
	cat >> ${WANPIPEMON_LEGACY_MAKEFILE} << ENDOFTEXT

BINDIR	= ${WAN_BIN_DIR}
DESTDIR	= ${WAN_BUILDDIR}
PROG	= wanpipemon_legacy
SRCS	= ${WANPIPEMON_LEGACY_SRCS}
CFLAGS	+= ${WANPIPEMON_LEGACY_CFLAGS}
LDFLAGS	+= ${WANPIPEMON_LEGACY_LDFLAGS}
COPTS	+= ${WANPIPEMON_LEGACY_COPTS}
${NOMAN_ARG} 	=

.include <bsd.prog.mk>
ENDOFTEXT
	eval "chmod +x $WANPIPEMON_LEGACY_MAKEFILE"

	########################################################
	# Create Mafile for WANCONFIG utility
	WANCONFIG_MAKEFILE=$WRKDIR/sources/wantools/wanconfig/Makefile
	WANCONFIG_SRCS="wanconfig.c"
	WANCONFIG_CFLAGS="${APPL_CFLAGS} -I../../../include"
	cat > $WANCONFIG_MAKEFILE << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma WANCONFIG utility
#

BINDIR	= ${WAN_BIN_DIR}
DESTDIR	= ${WAN_BUILDDIR}
PROG	= wanconfig
SRCS	= ${WANCONFIG_SRCS}
CFLAGS	+= -DWAN_HWEC ${WANCONFIG_CFLAGS}
${NOMAN_ARG} 	=

.include <bsd.prog.mk>
ENDOFTEXT
	eval "chmod +x $WANCONFIG_MAKEFILE"

	########################################################
	# Create Mafile for SDLADUMP utility
	SDLADUMP_MAKEFILE=$WRKDIR/sources/wantools/sdladump/Makefile
	SDLADUMP_SRCS="sdladump.c"
	SDLADUMP_CFLAGS="${APPL_CFLAGS} -I../../../include"
	cat > $SDLADUMP_MAKEFILE << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma SDLADUMP utility
#

BINDIR	= ${WAN_BIN_DIR}
DESTDIR	= ${WAN_BUILDDIR}
PROG	= sdladump
SRCS	= ${SDLADUMP_SRCS}
CFLAGS	+= ${SDLADUMP_CFLAGS}
${NOMAN_ARG} 	=

.include <bsd.prog.mk>
ENDOFTEXT
	eval "chmod +x $SDLADUMP_MAKEFILE"

	########################################################
	# Create Mafile for WANPIPEMON utility
	WANCFG_MAKEFILE=$WRKDIR/sources/wantools/wancfg/Makefile
	WANCFG_SRCS="conf_file_reader.cpp conf_file_writer.cpp cpp_string.cpp dialog_base.cpp dialog_yes_no.cpp input_box.cpp input_box_active_channels.cpp input_box_frame_relay_dlci_number.cpp input_box_number_of_dlcis.cpp input_box_number_of_logical_channels.cpp main.cpp menu_adsl_advanced_cfg.cpp menu_adsl_clock_type.cpp menu_adsl_coding_gain.cpp menu_adsl_encapsulation.cpp menu_adsl_exchange_type.cpp menu_adsl_framing_struct.cpp menu_adsl_rx_bin_adjust.cpp menu_adsl_standard.cpp menu_adsl_trellis.cpp menu_advanced_pci_configuration.cpp menu_aft_logical_channel_cfg.cpp menu_aft_logical_channels_list.cpp menu_base.cpp menu_chdlc_advanced_cfg.cpp menu_chdlc_basic_cfg.cpp menu_device_miscellaneous_options.cpp menu_frame_relay_advanced_dlci_configuration.cpp menu_frame_relay_advanced_global_configuration.cpp menu_frame_relay_arp.cpp menu_frame_relay_basic_cfg.cpp menu_frame_relay_cir_configuration.cpp menu_frame_relay_dlci_configuration.cpp menu_frame_relay_dlci_list.cpp menu_frame_relay_manual_or_auto_dlci_cfg.cpp menu_frame_relay_signalling.cpp menu_hardware_card_type.cpp menu_hardware_cpu_number.cpp menu_hardware_probe.cpp menu_hardware_select_comms_port.cpp menu_hardware_select_serial_clock_source.cpp menu_hardware_serial_card_advanced_options.cpp menu_hardware_serial_select_medium.cpp menu_hardware_setup.cpp menu_hardware_te1_card_advanced_options.cpp menu_hardware_te3_card_advanced_options.cpp menu_list_all_wanpipes.cpp menu_list_existing_wanpipes.cpp menu_main_configuration_options.cpp menu_net_interface_ip_configuration.cpp menu_net_interface_miscellaneous_options.cpp menu_net_interface_operation_mode.cpp menu_net_interface_setup.cpp menu_net_interfaces_list.cpp menu_new_device_configuration.cpp menu_ppp_basic_cfg.cpp menu_ppp_ip_mode.cpp menu_ppp_select_authentication_protocol.cpp menu_s508_io_port_select.cpp menu_s508_irq_select.cpp menu_s508_memory_addr.cpp menu_select_card_type_manualy.cpp menu_select_protocol.cpp menu_t1_lbo.cpp menu_e1_lbo.cpp menu_te1_clock_mode.cpp menu_te1_select_media.cpp menu_te3_select_media.cpp menu_te_select_framing.cpp menu_te_select_line_decoding.cpp menu_wan_channel_cfg.cpp net_interface_file_reader.cpp text_box.cpp text_box_yes_no.cpp wanrouter_rc_file_reader.cpp menu_wan_channel_cfg_v1.cpp menu_lapb_basic_cfg.cpp message_box.cpp menu_tdmv_law.cpp"

	WANCFG_LDADD="-ll -ly -lm -lstdc++"
	WANCFG_CFLAGS="${APPL_CXXFLAGS} -D_GNUC_ -I../../../include"
	cat > ${WANCFG_MAKEFILE} << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma WANCFG configurator utility
#
BINDIR	= ${WAN_BIN_DIR}
DESTDIR	= ${WAN_BUILDDIR}
PROG	= wancfg
CXXFLAGS+= ${WANCFG_CFLAGS}
LDADD	= ${WANCFG_LDADD}
ENDOFTEXT
	if [ "$OSYSTEM" = "OpenBSD" ]; then
		cat >> ${WANCFG_MAKEFILE} << ENDOFTEXT
WANCFG_SRCS=${WANCFG_SRCS}
SRCS=\${WANCFG_SRCS:.cc=.cpp}
NOMAN 	=
depend:
ENDOFTEXT
	else
		cat >> ${WANCFG_MAKEFILE} << ENDOFTEXT
SRCS=${WANCFG_SRCS}
${NOMAN_ARG} 	=
ENDOFTEXT
	fi
	cat >> ${WANCFG_MAKEFILE} << ENDOFTEXT

.include <bsd.prog.mk>
ENDOFTEXT
	eval "chmod +x $WANCFG_MAKEFILE"

	########################################################
	# Create Mafile for Sangoma lxdilog utility
	LXDIALOG_MAKEFILE=$WRKDIR/sources/wantools/lxdialog/Makefile
	LXDIALOG_SRCS="checklist.c menubox.c textbox.c yesno.c inputbox.c util.c lxdialog.c msgbox.c text_yesno.c menubox_back.c menu_text.c"
	LXDIALOG_CFLAGS="-Wall -Wstrict-prototypes -O2 -fomit-frame-pointer -DLOCALE -DCURSES_LOC=\"<ncurses.h>\"  -I../../../include"
	LXDIALOG_LDFLAGS="-s -L . ${NCURSES_LIB}"
	LXDIALOG_COPTS="${APPL_CFLAGS} -I${FT1_DIR} -I${LXDIALOG_DIR}"
	cat > $LXDIALOG_MAKEFILE << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma LXDIALOG utility
#

BINDIR	= ${WAN_BIN_DIR}
DESTDIR	= ${WAN_BUILDDIR}
PROG	= wanpipe_lxdialog
SRCS	= ${LXDIALOG_SRCS}
CFLAGS	+= ${LXDIALOG_CFLAGS}
LDFLAGS	+= ${LXDIALOG_LDFLAGS}
${NOMAN_ARG} 	=

.include <bsd.prog.mk>
ENDOFTEXT
	eval "chmod +x $LXDIALOG_MAKEFILE"

	########################################################
	# Create Mafile for FT1 utility
	FT1_MAKEFILE=$WRKDIR/sources/wantools/ft1/Makefile
	FT1_SRCS="ft1_config.c unixio.c"
	FT1_CFLAGS="${APPL_CFLAGS}  -I../../../include"
	cat > $FT1_MAKEFILE << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma FT1 utility
#

BINDIR	= ${WAN_BIN_DIR}
DESTDIR	= ${WAN_BUILDDIR}
PROG	= wanpipe_ft1exec
SRCS	= ${FT1_SRCS}
CFLAGS	+= ${FT1_CFLAGS}
${NOMAN_ARG} 	=

.include <bsd.prog.mk>
ENDOFTEXT
	eval "chmod +x $FT1_MAKEFILE"

	########################################################
	# Create Mafile for AFT Update utility
	WAN_AFTUP_MAKEFILE=$WRKDIR/sources/wantools/wan_aftup/Makefile
	WAN_AFTUP_SRCS="wan_aftup.c wan_aft_prg.c wan_aft_flash.c wan_aft_flash_shark.c wan_plxctrl.c"
	WAN_AFTUP_CFLAGS="${APPL_CFLAGS}  -I../../../include"
	cat > ${WAN_AFTUP_MAKEFILE} << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma WAN_AFTUP utility
#

BINDIR	= ${WAN_BIN_DIR}
DESTDIR	= ${WAN_BUILDDIR}
PROG	= wan_aftup
SRCS	= ${WAN_AFTUP_SRCS}
CFLAGS	+= ${WAN_AFTUP_CFLAGS}
${NOMAN_ARG} 	=

.include <bsd.prog.mk>
ENDOFTEXT
	eval "chmod +x $WAN_AFTUP_MAKEFILE"

	########################################################
	# Create Mafile for AFT PLX update utility
	WAN_PLXUP_MAKEFILE=$WRKDIR/sources/wantools/wan_plxctrl/Makefile
	WAN_PLXUP_SRCS="wan_plxup.c wan_plxctrl.c"
	WAN_PLXUP_CFLAGS="${APPL_CFLAGS}  -I../../../include"
	cat > ${WAN_PLXUP_MAKEFILE} << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma WAN_PLXUP utility
#

BINDIR	= ${WAN_BIN_DIR}
DESTDIR	= ${WAN_BUILDDIR}
PROG	= wan_plxup
SRCS	= ${WAN_PLXUP_SRCS}
CFLAGS	+= ${WAN_PLXUP_CFLAGS}
${NOMAN_ARG} 	=

.include <bsd.prog.mk>
ENDOFTEXT
	eval "chmod +x $WAN_PLXUP_MAKEFILE"

	########################################################
	# Create Mafile for WANEC_client utility
	WANEC_CLIENT_MAKEFILE=$WRKDIR/sources/wantools/wanec_client/Makefile
	WANEC_CLIENT_SRCS="wan_ecmain.c wan_ec_argy.c wan_ec_argl.c wanec_api.c wanec_api_lib.c"
	WANEC_CLIENT_CFLAGS="${APPL_CFLAGS} -O2  -I../../../include -I../wanec_apilib -I../../wanec/oct6100api -I../../wanec/oct6100api/include"
	WANEC_CLIENT_CLEANFILES="wan_ec_argy.c wan_ec_argy.h wan_ec_argl.c"
	cat > ${WANEC_CLIENT_MAKEFILE} << ENDOFTEXT

#
# ${DATE}
#
# Makefile for Sangoma WANEC_CLIENT utility
#
.PATH:	../wanec_apilib

YACC	= ${YACC}
LEX	= ${LEX}
BINDIR	= ${WAN_BIN_DIR}
DESTDIR	= ${WAN_BUILDDIR}

# Build Options.
PROG    	= wan_ec_client
SRCS		= ${WANEC_CLIENT_SRCS}
CFLAGS		+= ${WANEC_CLIENT_CFLAGS}
CLEANFILES	+= ${WANEC_CLIENT_CLEANFILES}
${NOMAN_ARG} 	=

wan_ec_argy.c:
	\$(YACC) -d -o wan_ec_argy.c wan_ec_arg.y

wan_ec_argl.c:
	\$(LEX)	-owan_ec_argl.c wan_ec_arg.l

.include <bsd.prog.mk>
ENDOFTEXT
	eval "chmod +x $WANEC_CLIENT_MAKEFILE"

	########################################################
	# Create Mafile for API CHDLC RCV utility
	WAN_API_CHDLC_RCV_MAKEFILE=$WRKDIR/sources/wantools/api/chdlc/rcv/Makefile
	cat > ${WAN_API_CHDLC_RCV_MAKEFILE} << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma API CHDLC RCV utility
#

PROG	= chdlc_rec
COPTS	+= -Wall -Wmissing-prototypes
${NOMAN_ARG} 	=

install:

.include <bsd.prog.mk>
ENDOFTEXT
	eval "chmod +x $WAN_API_CHDLC_RCV_MAKEFILE"

	########################################################
	# Create Mafile for API CHDLC SND utility
	WAN_API_CHDLC_SND_MAKEFILE=$WRKDIR/sources/wantools/api/chdlc/snd/Makefile
	cat > ${WAN_API_CHDLC_SND_MAKEFILE} << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma API CHDLC SND utility
#

PROG	= chdlc_snd
COPTS	+= -Wall -Wmissing-prototypes
${NOMAN_ARG} 	=

install:

.include <bsd.prog.mk>
ENDOFTEXT
	eval "chmod +x $WAN_API_CHDLC_SND_MAKEFILE"

	########################################################
	# Create Mafile for API FR RCV utility
	WAN_API_FR_RCV_MAKEFILE=$WRKDIR/sources/wantools/api/fr/rcv/Makefile
	cat > ${WAN_API_FR_RCV_MAKEFILE} << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma API FR RCV utility
#

PROG	= fr_rec
COPTS	+= -Wall -Wmissing-prototypes
${NOMAN_ARG} 	=

install:

.include <bsd.prog.mk>
ENDOFTEXT
	eval "chmod +x $WAN_API_FR_RCV_MAKEFILE"

	########################################################
	# Create Mafile for API FR SND utility
	WAN_API_FR_SND_MAKEFILE=$WRKDIR/sources/wantools/api/fr/snd/Makefile
	cat > ${WAN_API_FR_SND_MAKEFILE} << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma API FR SND utility
#

PROG	= fr_snd
COPTS	+= -Wall -Wmissing-prototypes
${NOMAN_ARG} 	=

install:

.include <bsd.prog.mk>
ENDOFTEXT
	eval "chmod +x $WAN_API_FR_SND_MAKEFILE"

	return 0
}

#
# Create Makefile files...
#
create_makefiles()
{
	WAN_KERNEL_CFLAGS=
	
	########################################################
	# Create global Mafile
	cat > $WRKDIR/Makefile << ENDOFTEXT
#
# ${DATE}
#
# Makefile for Sangoma
#
SUBDIR	= sources
.include <bsd.subdir.mk>
ENDOFTEXT
	eval "chmod +x $WRKDIR/Makefile"

	# Create Makefile.in
	create_makefilein

	# Create kernel modules Makefile
	if [ "$OSYSTEM" = "FreeBSD" ]; then
		create_freebsd_kernel_makefiles
	elif [ "$OSYSTEM" = "OpenBSD" ]; then
		create_openbsd_kernel_makefiles
	fi
   	if [ $? -ne 0 ]; then
		return 1
	fi
	create_appl_makefiles
   	if [ $? -ne 0 ]; then
		return 1
	fi
	return

}

get_zaptel_path()
{
	local	dir

	path=`find $1 -name 'zaptel.h'`
	if [ -z $path ]; then
		print
		print -e "\tZaptel sources are not found!"
		print
		return 1
	fi
	dir=${path%/*}
	if [ -f $dir/zaptel.h ]; then
		ZAPTEL_CFLAGS="-I$dir "
		return 0
	fi
	print
	print -e "\tZaptel headers are not found!"
	print
	return 1
}

init_global_params()
{

	if [ "$OSYSTEM" = "FreeBSD" ]; then
		KNAME=GENERIC
		KCONFIG_DIR=$PLATFORM/conf
      		KCONFIG=$SYSDIR/$KCONFIG_DIR/$KNAME
		KDRV_SRC=$PLATFORM/isa
		KERNEL_OPTIONS=options
		KOPTIONS=$SYSDIR/conf/${KERNEL_OPTIONS}
		OS_MAJOR_VER=${OSYSTEM_VER%%.*}
		OS_MINOR_VER=${OSYSTEM_VER%%-*}
		OS_MINOR_VER=${OS_MINOR_VER##*.}
		if [ $OS_MAJOR_VER -ge "5" ]; then
			KCOMPILE_DIR=$PLATFORM/compile
			#WAN_MODULE_DIR=${WAN_BASE}/lib/wanpipe
			WAN_MODULE_DIR=/boot/modules
		fi
	fi
	
	return 0
}


##############################################################################
##
PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin:/usr/pkg/bin
DATE=`date`
OSYSTEM=`uname -s`
PLATFORM=`uname -m`
OSYSTEM_VER=`uname -r`
PKG_NAME=$1
PKG_ACTION=$2
WAN_BASE=$3
PKG_ARG1=$4
PKG_ARG2=$5
SYSDIR=/usr/src/sys
WAN_BUILDDIR=/
WAN_BIN_DIR=${WAN_BASE}/sbin
WAN_BUILDDIR=/

YACC=yacc
LEX=lex

WRKDIR=`pwd`/work/$1

OUTPUT_TYPE=NORMAL

ZAPTEL_PORT=/usr/ports/misc/zaptel
ZAPTEL_CFLAGS=

DEFAULT_MODES="SCARD-FR-CHDLC-PPP-ADSL-AFT_TE1-AFT_TE3-AFT_SER-AFT_56K"
TDM_MODES="AFT_TE1-AFT_RM-TDM-HWEC"

MODES="$DEFAULT_MODES"

init_global_params

if [ -z "$PKG_ARG1" ]; then
	# No options are selected, compile both TDM and WAN
	PKG_ARG1="WITH_TDM_VOICE"
	PKG_ARG2="WITH_WAN_PROTOCOL"
fi
if [ "$PKG_ARG1" = "WITH_TDM_VOICE" ]; then
	MODES="${MODES}-${TDM_MODES}"
	get_zaptel_path $ZAPTEL_PORT
	if [ $? -ne 0 ]; then
		return 1
	fi
fi
NETGRAPH="NO"
if [ "$PKG_ARG1" = "WITH_WAN_PROTOCOL" ]; then
	NETGRAPH="YES"
elif [ -n "$PKG_ARG2" -a "$PKG_ARG2" = "WITH_WAN_PROTOCOL" ]; then
	NETGRAPH="YES"
fi
if [ "$NETGRAPH" = "YES" ]; then
	# Verify Netgraph option
	verify_netgraph
fi

enable_compilation_modes $MODES

# Create makefiles
create_makefiles
if [ $? -ne 0 ]; then
	return 1
fi

return 0
